package com.jiuqi.mde;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.Arrays;
import java.util.StringTokenizer;

public final class MDEDimValueSet implements Cloneable, Comparable {
   private MDEDimensionSet dimensions;
   private Object[] dimValues;

   public MDEDimValueSet(MDEDimensionSet dimensions) {
      this.dimensions = dimensions;
      this.dimValues = new Object[dimensions.size()];
   }

   public int size() {
      return this.dimensions.size();
   }

   public MDEDimensionSet dimensions() {
      return this.dimensions;
   }

   public MDEDimension getDimension(int index) {
      return this.dimensions.get(index);
   }

   public Object getValue(int index) {
      return this.dimValues[index];
   }

   public Object getValue(MDEDimension dimension) {
      int index = this.dimensions.indexOf(dimension);
      return index >= 0 ? this.dimValues[index] : null;
   }

   public Object getValue(String dimName) {
      int index = this.dimensions.indexOf(dimName);
      return index >= 0 ? this.dimValues[index] : null;
   }

   public void setValue(int index, Object value) {
      if (value == null) {
         this.dimValues[index] = null;
      } else if (this.dimensions.get(index).isString) {
         this.dimValues[index] = value.toString();
      } else if (value instanceof Double) {
         this.dimValues[index] = new Integer(((Double)value).intValue());
      } else {
         this.dimValues[index] = value;
      }

   }

   public void setValue(MDEDimension dimension, Object value) {
      int index = this.dimensions.indexOf(dimension);
      if (index >= 0) {
         this.setValue(index, value);
      }

   }

   public void setValue(String dimName, Object value) {
      int index = this.dimensions.indexOf(dimName);
      if (index >= 0) {
         this.setValue(index, value);
      }

   }

   public Object[] getDimValues() {
      return this.dimValues;
   }

   public void setDimValues(Object[] dimValues) {
      this.dimValues = dimValues;
   }

   public void assignValues(MDEDimValueSet source) {
      if (source != null) {
         int i;
         int count;
         if (this.dimensions == source.dimensions) {
            i = 0;

            for(count = source.size(); i < count; ++i) {
               this.dimValues[i] = source.dimValues[i];
            }
         } else {
            i = 0;

            for(count = source.size(); i < count; ++i) {
               this.setValue(source.dimensions.get(i), source.dimValues[i]);
            }
         }

      }
   }

   public void assignValues(MDEDimValueSet source, boolean assignNull) {
      if (source != null) {
         int i;
         int count;
         Object value;
         if (this.dimensions == source.dimensions) {
            i = 0;

            for(count = source.size(); i < count; ++i) {
               value = source.dimValues[i];
               if (assignNull || value != null) {
                  this.setValue(i, value);
               }
            }
         } else {
            i = 0;

            for(count = source.size(); i < count; ++i) {
               value = source.dimValues[i];
               if (assignNull || value != null) {
                  this.setValue(source.dimensions.get(i), value);
               }
            }
         }

      }
   }

   public void assignNullValues(MDEDimValueSet source) {
      if (source != null) {
         int i = 0;

         for(int count = this.dimensions.size(); i < count; ++i) {
            Object value = this.dimValues[i];
            if (value == null) {
               this.setValue(i, source.getValue(this.dimensions.get(i)));
            }
         }

      }
   }

   public void clear() {
      Arrays.fill(this.dimValues, (Object)null);
   }

   public Object clone() {
      MDEDimValueSet result = new MDEDimValueSet(this.dimensions);
      int i = 0;

      for(int count = this.dimensions.size(); i < count; ++i) {
         result.setValue(i, this.dimValues[i]);
      }

      return result;
   }

   public int compareTo(Object o) {
      if (this == o) {
         return 0;
      } else if (o == null) {
         return 1;
      } else if (this == null) {
         return -1;
      } else if (o instanceof MDEDimValueSet) {
         int result = this.dimensions.compareTo(((MDEDimValueSet)o).dimensions);
         if (result != 0) {
            return result;
         } else {
            int i = 0;

            for(int count = this.dimensions.size(); i < count; ++i) {
               Object o1 = this.dimValues[i];
               Object o2 = ((MDEDimValueSet)o).dimValues[i];
               if (o1 != o2) {
                  if (o1 == null) {
                     return -1;
                  }

                  if (o2 == null) {
                     return 1;
                  }

                  if (o1 instanceof Comparable) {
                     result = ((Comparable)o1).compareTo(o2);
                  } else {
                     result = o1.hashCode() - o2.hashCode();
                  }

                  if (result != 0) {
                     return result;
                  }
               }
            }

            return result;
         }
      } else {
         return this.hashCode() - o.hashCode();
      }
   }

   public int compareNoOrder(Object o) {
      if (this == o) {
         return 0;
      } else if (!(o instanceof MDEDimValueSet)) {
         return -1;
      } else {
         int result = this.dimensions.compareTo(((MDEDimValueSet)o).dimensions);
         if (result != 0) {
            return result;
         } else {
            int i = 0;

            for(int count = this.dimensions.size(); i < count; ++i) {
               if (!this.dimensions.get(i).name.equals("顺序号")) {
                  Object o1 = this.dimValues[i];
                  Object o2 = ((MDEDimValueSet)o).dimValues[i];
                  if (o1 != o2) {
                     if (o1 == null) {
                        return -1;
                     }

                     if (o2 == null) {
                        return 1;
                     }

                     if (o1 instanceof Comparable) {
                        result = ((Comparable)o1).compareTo(o2);
                     } else {
                        result = o1.hashCode() - o2.hashCode();
                     }

                     if (result != 0) {
                        return result;
                     }
                  }
               }
            }

            return result;
         }
      }
   }

   public boolean equals(Object o) {
      if (!(o instanceof MDEDimValueSet)) {
         return false;
      } else if (this.dimensions.compareTo(((MDEDimValueSet)o).dimensions) != 0) {
         return false;
      } else {
         int i = 0;

         for(int count = this.dimensions.size(); i < count; ++i) {
            Object o1 = this.dimValues[i];
            Object o2 = ((MDEDimValueSet)o).dimValues[i];
            if (o1 != o2) {
               if (o1 == null || o2 == null) {
                  return false;
               }

               if (!o1.equals(o2)) {
                  return false;
               }
            }
         }

         return true;
      }
   }

   public boolean matches(MDEDimValueSet speciafication) {
      if (speciafication == null) {
         return true;
      } else {
         int i = 0;

         for(int count = speciafication.dimensions.size(); i < count; ++i) {
            Object spec = speciafication.getValue(i);
            if (spec != null) {
               MDEDimension dimension = speciafication.dimensions.get(i);
               int index = this.dimensions.indexOf(dimension);
               if (index >= 0) {
                  Object value = this.getValue(index);
                  if (!spec.equals(value)) {
                     return false;
                  }
               }
            }
         }

         return true;
      }
   }

   protected boolean isNullValue(Object value) {
      return value == null || "".equals(value);
   }

   public boolean isEmpty() {
      for(int i = 0; i < this.dimValues.length; ++i) {
         if (!this.isNullValue(this.dimValues[i])) {
            return false;
         }
      }

      return true;
   }

   public boolean hasNullValue() {
      return this.hasNullValue(false);
   }

   public boolean hasNullValue(boolean includeOrder) {
      for(int i = 0; i < this.dimValues.length; ++i) {
         if (this.isNullValue(this.dimValues[i]) && (includeOrder || !"顺序号".equals(this.dimensions.get(i).name))) {
            return true;
         }
      }

      return false;
   }

   public String encodeData() {
      String result = "";

      for(int i = 0; i < this.dimensions.size(); ++i) {
         Object value = this.dimValues[i];
         String data = "";
         if (value != null) {
            if (this.dimensions.get(i).isString) {
               data = (String)value;
            } else {
               int numVal = value instanceof Integer ? (Integer)value : ((Double)value).intValue();
               data = Integer.toString(numVal);
            }
         }

         if (i > 0) {
            result = result + "&";
         }

         try {
            result = result + URLEncoder.encode(data, "GBK");
         } catch (UnsupportedEncodingException var6) {
            throw new RuntimeException("系统没有配置GBK字符集！", var6);
         }
      }

      return result;
   }

   public void decodeData(String encodedData) throws MDEException {
      if (encodedData != null) {
         try {
            int index = 0;

            for(StringTokenizer st = new StringTokenizer(encodedData, "&"); st.hasMoreTokens(); ++index) {
               String data = st.nextToken();

               try {
                  data = URLDecoder.decode(data, "GBK");
               } catch (UnsupportedEncodingException var6) {
                  UnsupportedEncodingException e = var6;
                  throw new RuntimeException("系统没有配置GBK字符集！", e);
               }

               if (this.dimensions.get(index).isString) {
                  this.dimValues[index] = data;
               } else {
                  this.dimValues[index] = Integer.valueOf(data);
               }
            }

         } catch (NumberFormatException var7) {
            NumberFormatException ex = var7;
            throw new MDEException(ex);
         }
      }
   }

   public void parseString(String strData) throws MDEException {
      try {
         StringTokenizer st = new StringTokenizer(strData, ";,");

         while(st.hasMoreTokens()) {
            String data = st.nextToken();
            int p = data.indexOf(61);
            if (p > 0) {
               MDEDimension dim = this.dimensions.find(data.substring(0, p).trim());
               if (dim != null) {
                  int index = this.dimensions.indexOf(dim);
                  data = data.substring(p + 1);
                  if (dim.isString) {
                     if (data.length() > 2 && data.charAt(0) == '"' && data.charAt(data.length() - 1) == '"') {
                        data = data.substring(1, data.length() - 2);
                     }

                     this.dimValues[index] = data;
                  } else {
                     this.dimValues[index] = Integer.valueOf(data);
                  }

                  ++index;
               }
            }
         }

      } catch (NumberFormatException var7) {
         NumberFormatException ex = var7;
         throw new MDEException(ex);
      }
   }

   public String toString() {
      StringBuffer result = new StringBuffer(64);
      boolean needComma = false;
      int i = 0;

      for(int count = this.dimensions.size(); i < count; ++i) {
         if (this.dimValues[i] != null) {
            MDEDimension dimension = this.dimensions.get(i);
            if (needComma) {
               result.append(", ");
            }

            result.append(dimension.name);
            result.append('=');
            if (dimension.isString) {
               result.append('"');
               result.append((String)this.dimValues[i]);
               result.append('"');
            } else if (this.dimValues[i] instanceof Integer) {
               result.append((Integer)this.dimValues[i]);
            } else {
               result.append(this.dimValues[i].toString());
            }

            needComma = true;
         }
      }

      return result.toString();
   }

   public String getSQLFilter() {
      return this.getSQLFilter(false);
   }

   public String getSQLFilter(boolean isPrepared) {
      return this.getSQLFilter((String)null, isPrepared);
   }

   public String getSQLFilter(String tablePrefix) {
      return this.getSQLFilter(tablePrefix, false);
   }

   public String getSQLFilter(String tablePrefix, boolean isPrepared) {
      StringBuffer filter = new StringBuffer(128);
      boolean needAND = false;
      int i = 0;

      for(int count = this.dimensions.size(); i < count; ++i) {
         if (this.dimValues[i] != null) {
            MDEDimension dimension = this.dimensions.get(i);
            if (needAND) {
               filter.append(" AND ");
            }

            filter.append(dimension.getSQLFilter(tablePrefix, this.dimValues[i], isPrepared));
            needAND = true;
         }
      }

      return filter.toString();
   }
}
